/* Freeware by Art Heimsoth <heimsoth@doglover.com>
   Copyright (c) Art Heimsoth 1997 - all rights reserved                   */

/* Rexx command file to add the SR utility to the utility diskettes
   produced from the option under Warp 4.0.  This command file may also
   work on previous versions of Warp with the previous utility diskettes,
   but I have not tested that to make sure...

   This command file does the following:
   - copies the SYSINSTX.COM file from diskette 0 to diskette 3
   - change config.sys on diskette 1 to cause the CMD.EXE to be executed,
     thus allowing for STARTUP.CMD to be used.
   - add the device= statement for the DualStor device driver module to
     the config.sys
   - adds the IP2x.SYS/EXE modules to the content of diskette 2.
   - creates a STARTUP.CMD file on diskette 2.
   - adds the KBDCALLS.DLL module to diskette 3
   - adds the rest of the DualStor modules needed to diskette 3

   When the utility diskettes are now booted, the startup.cmd will cause
   a set of instructions to be displayed on what operations can be done.
   None of the current capabilities of the utility diskettes are taken
   away that I am aware of, altho the shell program was changed - so there
   may be some obscure limitations that I am not aware of.              */

version = '1.0'
parse arg dskt

if RxFuncQuery('SysLoadFuncs') then do
  call rxfuncadd 'SysLoadFuncs', 'RexxUtil', 'SysLoadFuncs'
  call SysLoadFuncs
  end

if dskt = '' then
  dskt = 'A:'
if length(dskt) > 2 then
  dskt = left(dskt,2)
if right(dskt,1) <> ':' then do
  Say 'Invalid target drive given.'
  exit 8
  end

boot = syssearchpath('PATH','CMD.EXE')
if length(boot) > 2 then
  boot = left(boot,3)
kbd = stream(boot || 'OS2\DLL\KBDCALLS.DLL','c','query exists')
dstor = syssearchpath('PATH','SR.EXE')
if length(dstor) > 7 then
  dstor = left(dstor,length(dstor)-6)

if kbd = '' then do
  Say 'Unable to find the location of KBDCALLS.DLL - unable to continue.'
  exit 8
  end
if dstor = '' then do
  Say 'Unable to find the DualStor modules via the PATH - add the location'
  Say '  to the path statement and retry.'
  exit 8
  end

Say '                    MAKESR4 for DualStor/2 and Warp 4'
Say ''
strt.=''
strt.1 = '@echo off'
strt.2 = 'detach ip2xdmn.exe'
strt.3 = 'REM cmd file to display instructions for using utilities and DualStor'
strt.4 = 'REM SR command....   This is for Warp 4.0 only...'
strt.5 = 'REM'
strt.6 = '@echo .'
strt.7 = '@echo                      Warp 4.0 Utility Diskettes'
strt.8 = '@echo .'
strt.9 = '@echo Remove Utility Diskette 2 and Insert Utility Diskette 3 in order to'
strt.10= '@echo use the following utilities:'
strt.11= '@echo .'
strt.12= '@echo   FORMAT - format a partition'
strt.13= '@echo   FDISK  - work with your partitions'
strt.14= '@echo   CHKDSK - check the validity of a partition'
strt.15= '@echo   SYSINSTX - make an HPFS partition bootable after restore'
strt.16= '@echo   TEDIT  - display/edit a text file'
strt.17= '@echo   SR     - restore a partition from a DualStor tape'
strt.18= '@echo.'
strt.0=18

/* get the SYSINSTX.COM file from diskette 0                            */
ans = ''
filen = dskt || '\SYSINSTX.COM'
label = 'DISK 0'
do while(ans = '')
  Say 'Please insert Utility Diskette 0 in the' dskt 'drive and press enter.'
  parse linein ans
  ans = sysdriveinfo(dskt)
  parse var ans . free . dlbl
  if dlbl <> label then
    ans = ''
  end
'@copy' filen dstor

/* process the config.sys from diskette 1                               */
ans = ''
filen = dskt || '\CONFIG.SYS'
label = 'DISK 1'
do while(ans = '')
  Say 'Please insert Utility Diskette 1 in the' dskt 'drive and press enter.'
  parse linein ans
  ans = sysdriveinfo(dskt)
  parse var ans . free . dlbl
  if dlbl <> label then
    ans = ''
  end

conf.=''
conf.0=0
call stream filen,'c','open read'
do forever
  i=conf.0+1
  conf.i = linein(filen)
  conf.0=i
  if stream(filen,'state') <> 'READY' then leave
  end
call stream filen,'c','close'

/* change the protshell and set os2_shell statement                     */
pshel = ''
sshel = ''
mous = ''
do i=1 to conf.0
  if translate(left(conf.i,10)) = 'PROTSHELL=' then do
    conf.i = 'protshell=cmd.exe /k a:\startup.cmd'
    pshel = i
    end
  else if translate(left(word(conf.i,2),10)) = 'OS2_SHELL=' then do
    conf.i = 'set os2_shell=cmd.exe'
    sshel = i
    end
  else if translate(right(conf.i,9)) = 'MOUSE.SYS' & mous = '' then
    mous = i
  else if translate(right(conf.i,11)) = 'IP22DRV.SYS' then
    mous = 0
  end

/* re-write config.sys adding the DualStor device= statement            */
call sysfiledelete(filen)
rspace=0
do i=1 to conf.0
  rspace = rspace + length(conf.i) + 2
  end
rspace = ((rspace + 511) % 512) * 512
ans = sysdriveinfo(dskt)
parse var ans . free .
if free < rspace then do
  Say 'Insufficient space left on diskette.'
  Say '  Free space required =' rspace 'bytes.'
  call error
  end
call stream filen,'c','open write'
do i=1 to conf.0
  call lineout filen,conf.i
  if i = mous then
    call lineout filen,'device=ip22drv.sys'
  end
call stream filen,'c','close'
drop conf.

/* process adding the modules to diskette 2                             */
ans = ''
label = 'DISK 2'
do while(ans = '')
  Say 'Please insert Utility Diskette 2 in the' dskt 'drive and press enter.'
  parse linein ans
  ans = sysdriveinfo(dskt)
  parse var ans . free . dlbl
  if dlbl <> label then
    ans = ''
  end

if stream(dskt || '\IP22DRV.SYS','c','query exists') <> '' then
  call sysfiledelete dskt || '\IP22DRV.SYS'
if stream(dskt || '\IP2XDMN.EXE','c','query exists') <> '' then
  call sysfiledelete dskt || '\IP2XDMN.EXE'
if stream(dskt || '\STARTUP.CMD','c','query exists') <> '' then
  call sysfiledelete dskt || '\STARTUP.CMD'
rspace = 0
do i=1 to strt.0
  rspace = rspace + length(strt.i) + 2
  end
rspace = ((rspace + 511) % 512) * 512
rspace = rspace + (((stream(dstor || '\ip22drv.sys','c','query size') + 511) % 512) * 512)
rspace = rspace + (((stream(dstor || '\ip2xdmn.exe','c','query size') + 511) % 512) * 512)
ans = sysdriveinfo(dskt)
parse var ans . free .
if free < rspace then do
  Say 'Insufficient space left on diskette.'
  Say '  Free space required =' rspace 'bytes.'
  call error
  end

'@COPY' dstor || '\ip22drv.sys' dskt
'@COPY' dstor || '\ip2xdmn.exe' dskt
filen = dskt || '\STARTUP.CMD'
call stream filen,'c','open write'
do i=1 to strt.0
  call lineout filen,strt.i
  end
call stream filen,'c','close'

/* process adding the modules to diskette 3                             */
ans = ''
label = 'DISK 3'
do while(ans = '')
  Say 'Please insert Utility Diskette 3 in the' dskt 'drive and press enter.'
  parse linein ans
  ans = sysdriveinfo(dskt)
  parse var ans . free . dlbl
  if dlbl <> label then
    ans = ''
  end

files = 'KBDCALLS.DLL IPCRGUI.DLL IPBB.DLL IPBP.DLL IPNWUTIL.DLL IPQUAL.DLL'
files = files 'IPRST.DLL IPMB.DLL IPUCGEN.DLL SR.EXE SYSINSTX.COM'
tfile = files
rspace = 0
do while (tfile <> '')
  parse var tfile filen tfile
  if stream(dskt || '\' || filen,'c','query exists') <> '' then
    call sysfiledelete dskt || '\' || filen
  if rspace = 0 then
    rspace = ((stream(boot || 'OS2\DLL\' || filen,'c','query size') + 511) % 512) * 512
  else
    rspace = rspace + (((stream(dstor || filen,'c','query size') + 511) % 512) * 512)
  end

ans = sysdriveinfo(dskt)
parse var ans . free .
if free < rspace then do
  Say 'Insufficient space left on diskette.'
  Say '  Free space required =' rspace 'bytes.'
  call error
  end

do while(files <> '')
  parse var files filen files
  if filen = 'KBDCALLS.DLL' then
    '@copy' boot || 'OS2\DLL\' || filen dskt
  else
    '@copy' dstor || filen dskt
  end

call sysfiledelete dstor || 'SYSINSTX.COM'
Say 'Remove Utility Diskette 3 from diskette drive - MAKESR4 complete.'
exit

error:
 call sysfiledelete dstor || 'SYSINSTX.COM'
 Say 'MAKESR4 aborted due to the above error.'
 exit 8
