/* Freeware by Art Heimsoth <heimsoth@doglover.com>
   Copyright (c) Art Heimsoth 1997 - all rights reserved                   */

/* rexx exec to check the existance of the Nowhere subdirectory, and
   if present on the boot drive, check to see if it is empty and if
   it has EAs associated with it.  If so, then add a dummy directory
   entry to circumvent the problem with DualStor not saving EAs with
   empty directories.                                                   */

Version = '1.2'
if (rxfuncquery('rexxutil') = 1) then do
  Say 'Loading the Rexx Utilities package'
  call RxFuncAdd 'SysLoadFuncs', 'RexxUtil', 'SysLoadFuncs'
  call SysLoadFuncs
  end

signal on error name synerr
signal on syntax name synerr
signal on failure name synerr
signal on novalue name synerr

dname = '*'
boot = ''
parse arg boot .
if boot = '' then
  boot = syssearchpath('PATH','CMD.EXE')
if length(boot) > 2 then
  boot = left(boot,3)
dirname = boot || dname
Say 'Checking partition (drive):' boot
filet.=''
filet.0=0
files.0=0
'@DIR' dirname '/A:D /N | rxqueue'
call moveit
filet.0 = 0
if files.0 > 0 then do
  i=1
  do while(files.0 >= i)
    nest = filet.0
    dirname = subword(files.i,5) || '\*'
    direas = word(files.i,4)

/*  the following code, if enabled, will walk all the directories on the
    drive looking for empty directories with EAs attached and cause a
    dummy directory to be added.  This was found to not be needed, and it
    should not be enabled as it may cause other problems.               */
/*  if verify(" ^'(",dirname,'Match') > 0 then
      dirname = '"' || dirname || '"'
    '@DIR' dirname '/A:D /N | rxqueue'
    call moveit                                                         */

    dirname = subword(files.i,5) || '\*'
    filex.=''
    call sysfiletree dirname,'filex','D'
    dflag = filex.0
    if filex.0 > 0 then do
      l=filet.0+1
      filet.l = filex.0 'directories in' dirname
      filet.0 = l
      do k=1 to filex.0
        l=filet.0+1
        filet.l = filex.k
        filet.0=l
        end
      end
    filex.=''
    call sysfiletree dirname,'filex','F'
    fflag = filex.0
    if filex.0 > 0 then do
      l=filet.0+1
      filet.l = filex.0 'files in' dirname
      filet.0 = l
      do k=1 to filex.0
        l=filet.0+1
        filet.l = filex.k
        filet.0=l
        end
      end
    if fflag = 0 & dflag = 0 then do
      msg = 'EA bytes:' direas 'in' dirname
      l=filet.0+1
      if direas <> 0 then do
        filet.l = msg
        filet.0=l
        end
      else
        filet.0 = nest
      end
    else
      filet.0 = nest
    i=i+1
    end
  end
if filet.0 > 0 then do
  Say 'Following empty directories in root have EAs.  A dummy subdirectory of'
  Say '  DualStor will be added to allow DualStor/2 to backup and restore them.'
  do i=1 to filet.0
    fname = subword(filet.i,5)
    fname = left(fname,length(fname)-1) || 'DualStor'
    rcode = sysmkdir(fname)
    if rcode <> 0 then
      Say left(filet.i,length(filet.i)-1) '<--- MKDIR failed, rc =' rcode
    else
      Say left(filet.i,length(filet.i)-1) '<--- DualStor added'
    end
  end
else
  Say 'No empty directories in Root with EAs found.'
exit 0

moveit:
  do queued()
    l=filet.0+1
    parse pull filet.l
    if filet.l <> '' then do
      if word(filet.l,1) = 'Directory' then do
        dirname = subword(filet.l,3)
        if right(dirname,1) <> '\' then
          dirname = dirname || '\'
        end
      if wordpos('<DIR>',filet.l) > 0 & ,
            left(word(filet.l,words(filet.l)),1) <> '.' then do
        filet.0 = l
        fname = subword(filet.l,5)
        k=files.0+1
        files.k=subword(filet.l,1,4) dirname || fname
        files.0=k
        end
      end
    end
  return

synerr:
  errline = sigl
  linenbr= errline
  Say 'Unexpected error occurred.'
  if errortext(rc) = ' ' then
    Say 'Error on line' linenbr
  else
    Say 'Error on line' linenbr 'was 'errortext(rc)
  Say 'Error line: 'sourceline(errline)
  exit 8
